@@ -147,7 +147,7 @@ class TestLang2POCommand(test_convert.TestConvertCommand, TestLang2PO):
 
     def test_help(self, capsys):
         """tests getting help"""
-        options = test_convert.TestConvertCommand.test_help(self, capsys)
+        options = super().test_help(capsys)
         options = self.help_check(options, "-P, --pot")
         options = self.help_check(options, "--encoding=ENCODING")
         options = self.help_check(options, "--duplicates=DUPLICATESTYLE", last=True)
