@@ -566,5 +566,5 @@ class TestPO2RESXCommand(test_convert.TestConvertCommand, TestPO2RESX):
 
     def test_help(self, capsys):
         """Tests getting help"""
-        options = test_convert.TestConvertCommand.test_help(self, capsys)
+        options = super().test_help(capsys)
         options = self.help_check(options, "-t TEMPLATE, --template=TEMPLATE")
