@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2006-2009 Zuza Software Foundation
 #
@@ -20,13 +19,14 @@
 """Helper functions for working with XML."""
 
 import re
-import six
 
 from lxml import etree
 
 
 # some useful xpath expressions
-xml_preserve_ancestors = etree.XPath("ancestor-or-self::*[attribute::xml:space='preserve']")
+xml_preserve_ancestors = etree.XPath(
+    "ancestor-or-self::*[attribute::xml:space='preserve']"
+)
 """All ancestors with xml:space='preserve'"""
 
 xml_space_ancestors = etree.XPath("ancestor-or-self::*/attribute::xml:space")
@@ -47,20 +47,20 @@ def getText(node, xml_space="preserve"):
     """
     xml_space = getXMLspace(node, xml_space)
     if xml_space == "default":
-        return six.text_type(string_xpath_normalized(node))  # specific to lxml.etree
+        return str(string_xpath_normalized(node))  # specific to lxml.etree
     else:
-        return six.text_type(string_xpath(node))  # specific to lxml.etree
+        return str(string_xpath(node))  # specific to lxml.etree
 
     # If we want to normalise space and only preserve it when the directive
     # xml:space="preserve" is given in node or in parents, consider this code:
-    #xml_preserves = xml_preserve_ancestors(node)
-    #if xml_preserves and xml_preserves[-1] == "preserve":
+    # xml_preserves = xml_preserve_ancestors(node)
+    # if xml_preserves and xml_preserves[-1] == "preserve":
     #    return unicode(string_xpath(node)) # specific to lxml.etree
-    #else:
+    # else:
     #    return unicode(string_xpath_normalized(node)) # specific to lxml.etree
 
 
-XML_NS = 'http://www.w3.org/XML/1998/namespace'
+XML_NS = "http://www.w3.org/XML/1998/namespace"
 
 
 def getXMLlang(node):
@@ -77,7 +77,7 @@ def getXMLspace(node, default=None):
     """Gets the xml:space attribute on node"""
     value = node.get("{%s}space" % XML_NS)
     if value is None:
-        value = default
+        return default
     return value
 
 
@@ -96,9 +96,8 @@ def namespaced(namespace, name):
     This is needed throughout lxml.
     """
     if namespace:
-        return "{%s}%s" % (namespace, name)
-    else:
-        return name
+        return f"{{{namespace}}}{name}"
+    return name
 
 
 MULTIWHITESPACE_PATTERN = r"[\n\r\t ]+"
@@ -106,10 +105,8 @@ MULTIWHITESPACE_RE = re.compile(MULTIWHITESPACE_PATTERN, re.MULTILINE)
 
 
 def normalize_space(text):
-    """Normalize the given text for implementation of ``xml:space="default"``.
-    """
-    text = MULTIWHITESPACE_RE.sub(u" ", text)
-    return text
+    """Normalize the given text for implementation of ``xml:space="default"``."""
+    return MULTIWHITESPACE_RE.sub(" ", text)
 
 
 def normalize_xml_space(node, xml_space, remove_start=False):
@@ -117,14 +114,14 @@ def normalize_xml_space(node, xml_space, remove_start=False):
     given xml_space parameter.
     """
     xml_space = getXMLspace(node) or xml_space
-    if xml_space == 'preserve':
+    if xml_space == "preserve":
         return
     if node.text:
         node.text = normalize_space(node.text)
-        if remove_start and node.text[0] == u" ":
+        if remove_start and node.text[0] == " ":
             node.text = node.text.lstrip()
             remove_start = False
-        if len(node.text) > 0 and node.text.endswith(u" "):
+        if len(node.text) > 0 and node.text.endswith(" "):
             remove_start = True
         if len(node) == 0:
             node.text = node.text.rstrip()
@@ -135,7 +132,9 @@ def normalize_xml_space(node, xml_space, remove_start=False):
         normalize_xml_space(child, remove_start)
 
 
-def reindent(elem, level=0, indent="  ", max_level=4, skip=None, toplevel=True, leaves=None):
+def reindent(
+    elem, level=0, indent="  ", max_level=4, skip=None, toplevel=True, leaves=None
+):
     """Adjust indentation to match specification.
 
     Each nested tag is identified by indent string, up to
@@ -152,21 +151,40 @@ def reindent(elem, level=0, indent="  ", max_level=4, skip=None, toplevel=True,
         extra_i = i + indent
     if len(elem) and level < max_level:
         is_leave = leaves and elem.tag in leaves
-        if ((not elem.text or not elem.text.strip())
-                and getXMLspace(elem) != 'preserve'
-                and elem[0].tag is not etree.Entity
-                and not is_leave):
+        if (
+            (not elem.text or not elem.text.strip())
+            and getXMLspace(elem) != "preserve"
+            and elem[0].tag is not etree.Entity
+            and not is_leave
+        ):
             elem.text = extra_i
         if not elem.tail or not elem.tail.strip():
             elem.tail = i
         if not is_leave:
             for child in elem:
                 reindent(child, next_level, indent, max_level, skip, False, leaves)
-            if (not child.tail or not child.tail.strip()) and child.tag is not etree.Entity:
+            if (
+                not child.tail or not child.tail.strip()
+            ) and child.tag is not etree.Entity:
                 child.tail = i
     if toplevel:
         if not elem.tail or not elem.tail.strip():
-            elem.tail = ''
+            elem.tail = ""
     else:
         if not elem.tail or not elem.tail.strip():
             elem.tail = i
+
+
+def validate_char(c):
+    """
+    identify valid chars for XML, based on xmlIsChar_ch from
+    https://github.com/GNOME/libxml2/blob/master/include/libxml/chvalid.h
+    """
+    return (0x9 <= ord(c) <= 0xA) or (ord(c) == 0xD) or (0x20 <= ord(c))
+
+
+def valid_chars_only(s):
+    """
+    prevent to crash libxml with unexpected chars
+    """
+    return "".join(ch for ch in s if validate_char(ch))
