@@ -111,6 +111,7 @@ class BaseJsonUnit(base.DictUnit):
 
     def setid(self, value):
         self._id = value
+        self._unitid = None
 
     def getid(self):
         return self._id
@@ -120,7 +121,9 @@ class BaseJsonUnit(base.DictUnit):
 
     def __str__(self):
         """Converts to a string representation."""
-        return json.dumps(self.getvalue(), separators=(',', ': '), indent=4, ensure_ascii=False)
+        return json.dumps(
+            self.getvalue(), separators=(",", ": "), indent=4, ensure_ascii=False
+        )
 
     def converttarget(self):
         if issubclass(self._type, str):
@@ -155,23 +158,31 @@ class JsonFile(base.DictStore):
         """construct a JSON file, optionally reading in from inputfile."""
         super().__init__(**kwargs)
         self._filter = filter
-        self.filename = ''
-        self._file = ''
+        self.filename = ""
+        self._file = ""
         self.dump_args = {
-            'separators': (',', ': '),
-            'indent': 4,
-            'ensure_ascii': False,
+            "separators": (",", ": "),
+            "indent": 4,
+            "ensure_ascii": False,
         }
         if inputfile is not None:
             self.parse(inputfile)
 
     def serialize(self, out):
-        units = OrderedDict()
+        units = self.get_root_node()
         self.serialize_units(units)
         out.write(json.dumps(units, **self.dump_args).encode(self.encoding))
-        out.write(b'\n')
+        out.write(b"\n")
 
-    def _extract_units(self, data, stop=None, prev=None, name_node=None, name_last_node=None, last_node=None):
+    def _extract_units(
+        self,
+        data,
+        stop=None,
+        prev=None,
+        name_node=None,
+        name_last_node=None,
+        last_node=None,
+    ):
         """Recursive function to extract items from the data files
 
         :param data: the current branch to walk down
@@ -185,16 +196,20 @@ class JsonFile(base.DictStore):
             prev = self.UnitClass.IdClass([])
         if isinstance(data, dict):
             for k, v in data.items():
-                for x in self._extract_units(v, stop, prev + [('key', k)], k, None, data):
-                    yield x
+                yield from self._extract_units(
+                    v, stop, prev + [("key", k)], k, None, data
+                )
         elif isinstance(data, list):
             for i, item in enumerate(data):
-                for x in self._extract_units(item, stop, prev + [('index', i)], i, name_node, data):
-                    yield x
+                yield from self._extract_units(
+                    item, stop, prev + [("index", i)], i, name_node, data
+                )
         # apply filter
-        elif (stop is None or
-              (isinstance(last_node, dict) and name_node in stop) or
-              (isinstance(last_node, list) and name_last_node in stop)):
+        elif (
+            stop is None
+            or (isinstance(last_node, dict) and name_node in stop)
+            or (isinstance(last_node, list) and name_last_node in stop)
+        ):
 
             unit = self.UnitClass(data, name_node)
             unit.set_unitid(prev)
@@ -202,10 +217,10 @@ class JsonFile(base.DictStore):
 
     def parse(self, input):
         """parse the given file or file source string"""
-        if hasattr(input, 'name'):
+        if hasattr(input, "name"):
             self.filename = input.name
-        elif not getattr(self, 'filename', ''):
-            self.filename = ''
+        elif not getattr(self, "filename", ""):
+            self.filename = ""
         if hasattr(input, "read"):
             src = input.read()
             input.close()
@@ -225,7 +240,6 @@ class JsonFile(base.DictStore):
 
 
 class JsonNestedUnit(BaseJsonUnit):
-
     def storevalues(self, output):
         self.storevalue(output, self.converttarget())
 
@@ -238,13 +252,11 @@ class JsonNestedFile(JsonFile):
 
 class WebExtensionJsonUnit(BaseJsonUnit):
     def storevalues(self, output):
-        value = OrderedDict((
-            ('message', self.target),
-        ))
+        value = OrderedDict((("message", self.target),))
         if self.notes:
-            value['description'] = self.notes
+            value["description"] = self.notes
         if self.placeholders:
-            value['placeholders'] = self.placeholders
+            value["placeholders"] = self.placeholders
         self.storevalue(output, value)
 
 
@@ -259,13 +271,21 @@ class WebExtensionJsonFile(JsonFile):
 
     UnitClass = WebExtensionJsonUnit
 
-    def _extract_units(self, data, stop=None, prev=None, name_node=None, name_last_node=None, last_node=None):
+    def _extract_units(
+        self,
+        data,
+        stop=None,
+        prev=None,
+        name_node=None,
+        name_last_node=None,
+        last_node=None,
+    ):
         for item, value in data.items():
             unit = self.UnitClass(
-                value.get('message', ''),
+                value.get("message", ""),
                 item,
-                value.get('description', ''),
-                value.get('placeholders', None)
+                value.get("description", ""),
+                value.get("placeholders", None),
             )
             unit.setid(item)
             yield unit
@@ -285,15 +305,15 @@ class I18NextUnit(JsonNestedUnit):
     def target(self, target):
         def get_base(item):
             """Return base name for plurals"""
-            if '_0' in item[0]:
+            if "_0" in item[0]:
                 return item[0][:-2]
             else:
                 return item[0]
 
         def get_plurals(count, base):
             if count <= 2:
-                return [base, base + '_plural'][:count]
-            return ['{0}_{1}'.format(base, i) for i in range(count)]
+                return [base, base + "_plural"][:count]
+            return [f"{base}_{i}" for i in range(count)]
 
         if isinstance(target, multistring):
             count = len(target.strings)
@@ -325,12 +345,24 @@ class I18NextFile(JsonNestedFile):
 
     UnitClass = I18NextUnit
 
-    def _extract_units(self, data, stop=None, prev=None, name_node=None, name_last_node=None, last_node=None):
+    def _extract_units(
+        self,
+        data,
+        stop=None,
+        prev=None,
+        name_node=None,
+        name_last_node=None,
+        last_node=None,
+    ):
         if prev is None:
             prev = self.UnitClass.IdClass([])
         if isinstance(data, dict):
-            plurals_multiple = [key.rsplit('_', 1)[0] for key in data if key.endswith('_0')]
-            plurals_simple = [key.rsplit('_', 1)[0] for key in data if key.endswith('_plural')]
+            plurals_multiple = [
+                key.rsplit("_", 1)[0] for key in data if key.endswith("_0")
+            ]
+            plurals_simple = [
+                key.rsplit("_", 1)[0] for key in data if key.endswith("_plural")
+            ]
             processed = set()
 
             for k, v in data.items():
@@ -338,19 +370,19 @@ class I18NextFile(JsonNestedFile):
                 if k in processed:
                     continue
                 plurals = []
-                plural_base = ''
-                if k in plurals_simple or k + '_plural' in plurals_simple:
-                    if k.endswith('_plural'):
+                plural_base = ""
+                if k in plurals_simple or k + "_plural" in plurals_simple:
+                    if k.endswith("_plural"):
                         plural_base = k[:-7]
                     else:
                         plural_base = k
                     plurals_simple.remove(plural_base)
-                    plurals = [k, k + '_plural']
-                elif '_' in k:
-                    plural_base, digit = k.rsplit('_', 1)
+                    plurals = [k, k + "_plural"]
+                elif "_" in k:
+                    plural_base, digit = k.rsplit("_", 1)
                     if plural_base in plurals_multiple and digit.isdigit():
                         plurals_multiple.remove(plural_base)
-                        plurals = ['{0}_{1}'.format(plural_base, order) for order in range(10)]
+                        plurals = [f"{plural_base}_{order}" for order in range(10)]
                 if plurals:
                     sources = []
                     items = []
@@ -361,19 +393,19 @@ class I18NextFile(JsonNestedFile):
                         sources.append(data[key])
                         items.append(key)
                     unit = self.UnitClass(multistring(sources), items)
-                    newid = prev + [('key', plural_base)]
+                    newid = prev + [("key", plural_base)]
                     unit.set_unitid(newid)
                     yield unit
                     continue
 
-                for x in self._extract_units(v, stop, prev + [('key', k)], k, None, data):
-                    yield x
+                yield from self._extract_units(
+                    v, stop, prev + [("key", k)], k, None, data
+                )
         else:
             parent = super()._extract_units(
                 data, stop, prev, name_node, name_last_node, last_node
             )
-            for x in parent:
-                yield x
+            yield from parent
 
 
 class GoI18NJsonUnit(BaseJsonUnit):
@@ -385,15 +417,16 @@ class GoI18NJsonUnit(BaseJsonUnit):
             strings = list(target.strings)
             if len(self._store.plural_tags) > len(target.strings):
                 strings += [""] * (len(self._store.plural_tags) - len(target.strings))
-            target = OrderedDict([
-                (plural, strings[offset]) for offset, plural in enumerate(self._store.plural_tags)
-            ])
-        value = OrderedDict((
-            ('id', self.getid()),
-        ))
+            target = OrderedDict(
+                [
+                    (plural, strings[offset])
+                    for offset, plural in enumerate(self._store.plural_tags)
+                ]
+            )
+        value = OrderedDict((("id", self.getid()),))
         if self.notes:
-            value['description'] = self.notes
-        value['translation'] = target
+            value["description"] = self.notes
+        value["translation"] = target
         return value
 
 
@@ -412,50 +445,70 @@ class GoI18NJsonFile(JsonFile):
     def plural_tags(self):
         locale = self.gettargetlanguage()
         if locale:
-            locale = locale.replace('_', '-').split('-')[0]
+            locale = locale.replace("_", "-").split("-")[0]
         else:
             locale = "en"
-        return plural_tags.get(locale, plural_tags['en'])
+        return plural_tags.get(locale, plural_tags["en"])
 
-    def _extract_units(self, data, stop=None, prev=None, name_node=None, name_last_node=None, last_node=None):
+    def _extract_units(
+        self,
+        data,
+        stop=None,
+        prev=None,
+        name_node=None,
+        name_last_node=None,
+        last_node=None,
+    ):
         for value in data:
-            translation = value.get('translation', '')
+            translation = value.get("translation", "")
             if isinstance(translation, dict):
                 # Ordered list of plurals
                 translation = multistring(
-                    [translation.get(key) for key in cldr_plural_categories if key in translation]
+                    [
+                        translation.get(key)
+                        for key in cldr_plural_categories
+                        if key in translation
+                    ]
                 )
             unit = self.UnitClass(
                 translation,
-                value.get('id', ''),
-                value.get('description', ''),
+                value.get("id", ""),
+                value.get("description", ""),
             )
-            unit.setid(value.get('id', ''))
+            unit.setid(value.get("id", ""))
             yield unit
 
     def serialize(self, out):
         units = [unit.getvalue() for unit in self.units]
         out.write(json.dumps(units, **self.dump_args).encode(self.encoding))
-        out.write(b'\n')
+        out.write(b"\n")
 
 
 class ARBJsonUnit(BaseJsonUnit):
     ID_FORMAT = "{}"
 
-    def __init__(self, source=None, item=None, notes=None, placeholders=None, metadata=None, **kwargs):
+    def __init__(
+        self,
+        source=None,
+        item=None,
+        notes=None,
+        placeholders=None,
+        metadata=None,
+        **kwargs,
+    ):
         super().__init__(source, item, notes, placeholders, **kwargs)
         self.metadata = metadata or {}
 
     def storevalues(self, output):
         if self.notes:
-            self.metadata['description'] = self.notes
+            self.metadata["description"] = self.notes
         identifier = self.getid()
         if identifier == "@":
             for key, value in self.metadata.items():
                 self.storevalue(output, value, override_key=key)
         else:
             self.storevalue(output, self.target, override_key=identifier)
-            self.storevalue(output, self.metadata, override_key='@{}'.format(identifier))
+            self.storevalue(output, self.metadata, override_key=f"@{identifier}")
 
     def isheader(self):
         return self._id == "@"
@@ -475,14 +528,24 @@ class ARBJsonFile(JsonFile):
     def __init__(self, inputfile=None, filter=None, **kwargs):
         super().__init__(inputfile, filter, **kwargs)
         self.dump_args = {
-            'separators': (',', ': '),
-            'indent': 2,
-            'ensure_ascii': False,
+            "separators": (",", ": "),
+            "indent": 2,
+            "ensure_ascii": False,
         }
 
-    def _extract_units(self, data, stop=None, prev=None, name_node=None, name_last_node=None, last_node=None):
+    def _extract_units(
+        self,
+        data,
+        stop=None,
+        prev=None,
+        name_node=None,
+        name_last_node=None,
+        last_node=None,
+    ):
         # Extract metadata as header
-        metadata = OrderedDict([(key, value) for key, value in data.items() if key.startswith("@@")])
+        metadata = OrderedDict(
+            [(key, value) for key, value in data.items() if key.startswith("@@")]
+        )
         if metadata:
             unit = self.UnitClass(metadata=metadata)
             unit.setid("@")
@@ -491,12 +554,12 @@ class ARBJsonFile(JsonFile):
         for item, value in data.items():
             if item.startswith("@"):
                 continue
-            metadata = data.get("@{}".format(item), {})
+            metadata = data.get(f"@{item}", {})
             unit = self.UnitClass(
                 value,
                 item,
-                metadata.get('description', ''),
-                metadata.get('placeholders', None),
+                metadata.get("description", ""),
+                metadata.get("placeholders", None),
                 metadata=metadata,
             )
             unit.setid(item)
