@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2002-2007 Zuza Software Foundation
 # Copyright 2016 F Wolff
@@ -19,7 +18,6 @@
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 import re
-import six
 
 
 """
@@ -35,24 +33,23 @@ From the GNU gettext manual:
      msgstr TRANSLATED-STRING
 """
 
-SINGLE_BYTE_ENCODING = 'iso-8859-1'
-isspace = six.text_type.isspace
-find = six.text_type.find
-rfind = six.text_type.rfind
-startswith = six.text_type.startswith
+SINGLE_BYTE_ENCODING = "iso-8859-1"
+isspace = str.isspace
+find = str.find
+rfind = str.rfind
+startswith = str.startswith
 append = list.append
 decode = bytes.decode
 
 
-class ParseState(object):
-
+class ParseState:
     def __init__(self, input_iterator, UnitClass, encoding=SINGLE_BYTE_ENCODING):
         # A single-byte encoding is first defined to be able to read the header
         # without risking UnicodeDecodeErrors. As soon as the header is parsed,
         # the encoding defined in the header is used for re-encoding the header
         # and for decoding all further strings.
         self._input_iterator = input_iterator
-        self.next_line = ''
+        self.next_line = ""
         self.lineno = 0
         self.eof = False
         self.encoding = encoding
@@ -62,8 +59,7 @@ class ParseState(object):
     def decode(self, string):
         if self.encoding is not None:
             return decode(string, self.encoding)
-        else:
-            return string
+        return string
 
     def read_line(self):
         current = self.next_line
@@ -76,7 +72,7 @@ class ParseState(object):
                 self.next_line = next(self._input_iterator)
                 self.lineno += 1
         except StopIteration:
-            self.next_line = u''
+            self.next_line = ""
             self.eof = True
         else:
             if isinstance(self.next_line, bytes) and self.encoding is not None:
@@ -94,53 +90,59 @@ def read_prevmsgid_lines(parse_state):
     """
     prevmsgid_lines = []
     next_line = parse_state.next_line
-    while startswith(next_line, '#| ') or startswith(next_line, '| '):
+    while startswith(next_line, "#|") or startswith(next_line, "|"):
         content = parse_state.read_line()
-        prefix_len = content.index('| ')
-        content = content[prefix_len+2:]
+        prefix_len = content.index("|") + 1
+        while content[prefix_len] == " ":
+            prefix_len += 1
+        content = content[prefix_len:]
         append(prevmsgid_lines, content)
         next_line = parse_state.next_line
     return prevmsgid_lines
 
 
 def parse_prev_msgctxt(parse_state, unit):
-    parse_message(parse_state, 'msgctxt', 7, unit.prev_msgctxt)
+    parse_message(parse_state, "msgctxt", 7, unit.prev_msgctxt)
     return len(unit.prev_msgctxt) > 0
 
 
 def parse_prev_msgid(parse_state, unit):
-    parse_message(parse_state, 'msgid', 5, unit.prev_msgid)
+    parse_message(parse_state, "msgid", 5, unit.prev_msgid)
     return len(unit.prev_msgid) > 0
 
 
 def parse_prev_msgid_plural(parse_state, unit):
-    parse_message(parse_state, 'msgid_plural', 12, unit.prev_msgid_plural)
+    parse_message(parse_state, "msgid_plural", 12, unit.prev_msgid_plural)
     return len(unit.prev_msgid_plural) > 0
 
 
 def parse_comment(parse_state, unit):
     next_line = parse_state.next_line.lstrip()
-    if len(next_line) > 0 and next_line[0] in ('#', '|'):
+    if next_line and next_line[0] in ("#", "|"):
         next_char = next_line[1]
-        if next_char == '.':
+        if next_char == ".":
             append(unit.automaticcomments, next_line)
-        elif next_line[0] == '|' or next_char == '|':
+        elif next_line[0] == "|" or next_char == "|":
+            parsed = False
             # Read all the lines starting with #|
             prevmsgid_lines = read_prevmsgid_lines(parse_state)
             # Create a parse state object that holds these lines
             ps = parse_state.new_input(iter(prevmsgid_lines))
             # Parse the msgctxt if any
-            parse_prev_msgctxt(ps, unit)
+            parsed |= parse_prev_msgctxt(ps, unit)
             # Parse the msgid if any
-            parse_prev_msgid(ps, unit)
+            parsed |= parse_prev_msgid(ps, unit)
             # Parse the msgid_plural if any
-            parse_prev_msgid_plural(ps, unit)
+            parsed |= parse_prev_msgid_plural(ps, unit)
+            # Fail with error in csae nothing was parsed
+            if not parsed:
+                raise ValueError(f"Syntax error on line {parse_state.lineno}")
             return parse_state.next_line
-        elif next_char == ':':
+        elif next_char == ":":
             append(unit.sourcecomments, next_line)
-        elif next_char == ',':
+        elif next_char == ",":
             append(unit.typecomments, next_line)
-        elif next_char == '~':
+        elif next_char == "~":
             # Special case: we refuse to parse obsoletes: they are done
             # elsewhere to ensure we reuse the normal unit parsing code
             return None
@@ -154,24 +156,23 @@ def parse_comment(parse_state, unit):
 def parse_comments(parse_state, unit):
     if not parse_comment(parse_state, unit):
         return None
-    else:
-        while parse_comment(parse_state, unit):
-            pass
-        return True
+    while parse_comment(parse_state, unit):
+        pass
+    return True
 
 
 def read_obsolete_lines(parse_state):
     """Read all the lines belonging to the current unit if obsolete."""
     obsolete_lines = []
     next_line = parse_state.next_line
-    while startswith(next_line, '#~'):
+    while startswith(next_line, "#~"):
         content = parse_state.read_line()[2:].lstrip()
         append(obsolete_lines, content)
         next_line = parse_state.next_line
-        if startswith(content, 'msgstr'):
+        if startswith(content, "msgstr"):
             # now we saw a msgstr, so we need to become more conservative to
             # avoid parsing into the following unit
-            while startswith(next_line, '#~ "') or startswith(next_line, '#~ msgstr'):
+            while startswith(next_line, '#~ "') or startswith(next_line, "#~ msgstr"):
                 content = parse_state.read_line()[3:]
                 append(obsolete_lines, content)
                 next_line = parse_state.next_line
@@ -195,18 +196,15 @@ def parse_quoted(parse_state, start_pos=0):
     if left == start_pos or isspace(line[start_pos:left]):
         right = rfind(line, '"')
         if left != right:
-            return parse_state.read_line()[left:right+1]
-        else:
-            # There is no terminating quote, so we append an extra quote, but
-            # we also ignore the newline at the end (therefore the -1)
-            return parse_state.read_line()[left:-1] + '"'
+            return parse_state.read_line()[left : right + 1]
+        raise ValueError("end-of-line within string")
     return None
 
 
 def parse_msg_comment(parse_state, msg_comment_list, string):
     while string is not None:
         append(msg_comment_list, string)
-        if find(string, '\\n') > -1:
+        if find(string, "\\n") > -1:
             return parse_quoted(parse_state)
         string = parse_quoted(parse_state)
     return None
@@ -222,32 +220,38 @@ def parse_multiple_quoted(parse_state, msg_list, msg_comment_list, first_start_p
             string = parse_msg_comment(parse_state, msg_comment_list, string)
 
 
-def parse_message(parse_state, start_of_string, start_of_string_len, msg_list, msg_comment_list=None):
+def parse_message(
+    parse_state, start_of_string, start_of_string_len, msg_list, msg_comment_list=None
+):
     if startswith(parse_state.next_line, start_of_string):
-        return parse_multiple_quoted(parse_state, msg_list, msg_comment_list, start_of_string_len)
+        return parse_multiple_quoted(
+            parse_state, msg_list, msg_comment_list, start_of_string_len
+        )
 
 
 def parse_msgctxt(parse_state, unit):
-    parse_message(parse_state, 'msgctxt', 7, unit.msgctxt)
+    parse_message(parse_state, "msgctxt", 7, unit.msgctxt)
     return len(unit.msgctxt) > 0
 
 
 def parse_msgid(parse_state, unit):
-    parse_message(parse_state, 'msgid', 5, unit.msgid, unit.msgidcomments)
+    parse_message(parse_state, "msgid", 5, unit.msgid, unit.msgidcomments)
     return len(unit.msgid) > 0 or len(unit.msgidcomments) > 0
 
 
 def parse_msgstr(parse_state, unit):
-    parse_message(parse_state, 'msgstr', 6, unit.msgstr)
+    parse_message(parse_state, "msgstr", 6, unit.msgstr)
     return len(unit.msgstr) > 0
 
 
 def parse_msgid_plural(parse_state, unit):
-    parse_message(parse_state, 'msgid_plural', 12, unit.msgid_plural, unit.msgid_pluralcomments)
+    parse_message(
+        parse_state, "msgid_plural", 12, unit.msgid_plural, unit.msgid_pluralcomments
+    )
     return len(unit.msgid_plural) > 0 or len(unit.msgid_pluralcomments) > 0
 
 
-MSGSTR_ARRAY_ENTRY_LEN = len('msgstr[')
+MSGSTR_ARRAY_ENTRY_LEN = len("msgstr[")
 
 
 def add_to_dict(msgstr_dict, line, right_bracket_pos, entry):
@@ -259,22 +263,20 @@ def add_to_dict(msgstr_dict, line, right_bracket_pos, entry):
 
 def get_entry(parse_state, right_bracket_pos):
     entry = []
-    parse_message(parse_state, 'msgstr[', right_bracket_pos + 1, entry)
+    parse_message(parse_state, "msgstr[", right_bracket_pos + 1, entry)
     return entry
 
 
 def parse_msgstr_array_entry(parse_state, msgstr_dict):
     line = parse_state.next_line
-    right_bracket_pos = find(line, ']', MSGSTR_ARRAY_ENTRY_LEN)
+    right_bracket_pos = find(line, "]", MSGSTR_ARRAY_ENTRY_LEN)
     if right_bracket_pos >= 0:
         entry = get_entry(parse_state, right_bracket_pos)
-        if len(entry) > 0:
+        if entry:
             add_to_dict(msgstr_dict, line, right_bracket_pos, entry)
             return True
-        else:
-            return False
-    else:
         return False
+    return False
 
 
 def parse_msgstr_array(parse_state, unit):
@@ -289,20 +291,18 @@ def parse_msgstr_array(parse_state, unit):
 
 
 def parse_plural(parse_state, unit):
-    if parse_msgid_plural(parse_state, unit) and \
-       (parse_msgstr_array(parse_state, unit) or parse_msgstr(parse_state, unit)):
-        return True
-    else:
-        return False
+    return bool(
+        parse_msgid_plural(parse_state, unit)
+        and (parse_msgstr_array(parse_state, unit) or parse_msgstr(parse_state, unit))
+    )
 
 
 def parse_msg_entries(parse_state, unit):
     parse_msgctxt(parse_state, unit)
-    if parse_msgid(parse_state, unit) and \
-       (parse_msgstr(parse_state, unit) or parse_plural(parse_state, unit)):
-        return True
-    else:
-        return False
+    return bool(
+        parse_msgid(parse_state, unit)
+        and (parse_msgstr(parse_state, unit) or parse_plural(parse_state, unit))
+    )
 
 
 def parse_unit(parse_state, unit=None):
@@ -314,22 +314,25 @@ def parse_unit(parse_state, unit=None):
     parsed_msg_entries = parse_msg_entries(parse_state, unit)
     if parsed_comments or parsed_msg_entries:
         return unit
-    else:
-        return None
+    return None
 
 
 def set_encoding(parse_state, store, unit):
     charset = None
-    if isinstance(unit.msgstr, list) and len(unit.msgstr) and isinstance(unit.msgstr[0], six.string_types):
+    if (
+        isinstance(unit.msgstr, list)
+        and unit.msgstr
+        and isinstance(unit.msgstr[0], str)
+    ):
         charset = re.search("charset=([^\\s\\\\n]+)", "".join(unit.msgstr))
     if charset:
         encoding = charset.group(1)
-        if encoding != 'CHARSET':
+        if encoding != "CHARSET":
             store._encoding = encoding
         else:
-            store._encoding = 'utf-8'
+            store._encoding = "utf-8"
     else:
-        store._encoding = 'utf-8'
+        store._encoding = "utf-8"
     parse_state.encoding = store._encoding
 
 
@@ -343,15 +346,27 @@ def decode_header(unit, decode):
     re-encode it to decode values with the proper encoding defined in the header
     (using decode_list above).
     """
-    for attr in ('msgctxt', 'msgid', 'msgid_pluralcomments',
-                 'msgid_plural', 'msgstr',
-                 'othercomments', 'automaticcomments', 'sourcecomments',
-                 'typecomments', 'msgidcomments'):
+    for attr in (
+        "msgctxt",
+        "msgid",
+        "msgid_pluralcomments",
+        "msgid_plural",
+        "msgstr",
+        "othercomments",
+        "automaticcomments",
+        "sourcecomments",
+        "typecomments",
+        "msgidcomments",
+    ):
         element = getattr(unit, attr)
         if isinstance(element, list):
             setattr(unit, attr, decode_list(element, decode))
         else:
-            setattr(unit, attr, dict([(key, decode_list(value, decode)) for key, value in element.items()]))
+            setattr(
+                unit,
+                attr,
+                {key: decode_list(value, decode) for key, value in element.items()},
+            )
 
 
 def parse_header(parse_state, store):
@@ -376,4 +391,4 @@ def parse_units(parse_state, store):
         store.addunit(unit)
         unit = parse_unit(parse_state)
     if not parse_state.eof:
-        raise ValueError('Syntax error on line {}'.format(parse_state.lineno))
+        raise ValueError(f"Syntax error on line {parse_state.lineno}")
